<?php
/*
 * Plugin Name: Tickera - Delete Check-ins per Event
 * Plugin URI: http://tickera.com/
 * Description: Adds a button named DELETE CHECKINS to Tickera Settings -> System tab which deletes check-ins base on the selected events
 * Author: Tickera.com
 * Author URI: http://tickera.com/
 * Version: 1.0
 * TextDomain: tc
 * Domain Path: /languages/
 * Copyright 2018 Tickera (http://tickera.com/)
 */

if ( !defined( 'ABSPATH' ) )
    exit; // Exit if accessed directly

if ( !class_exists( 'TC_Delete_Check_Ins_Per_Event' ) ) {

    class TC_Delete_Check_Ins_Per_Event {

        var $version = '1.0';
        var $title = 'Tickera - Delete all Check-ins';
        var $name = 'tickera-delete-checkins-per-event';
        var $dir_name = 'tickera-delete-checkins-per-event';
        var $location = 'plugins';
        var $plugin_dir = '';
        var $plugin_url = '';

        function __construct() {
            self::init_vars();
            add_action( 'tc_after_system', array( &$this, 'tc_delete_checkins_per_event' ) );
            add_action( 'admin_init', array( &$this, 'process_deletion' ) );
        }

        function init_vars() {
            if (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . $this->dir_name . '/' . basename(__FILE__))) {
                $this->location = 'subfolder-plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/' . $this->dir_name . '/';
                $this->plugin_url = plugins_url('/', __FILE__);

            } else if (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location = 'plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/';
                $this->plugin_url = plugins_url('/', __FILE__);

            } else if (is_multisite() && defined('WPMU_PLUGIN_URL') && defined('WPMU_PLUGIN_DIR') && file_exists(WPMU_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location = 'mu-plugins';
                $this->plugin_dir = WPMU_PLUGIN_DIR;
                $this->plugin_url = WPMU_PLUGIN_URL;
            } else {
                wp_die(sprintf(__('There was an issue determining where %s is installed. Please reinstall it.', 'tc'), $this->title));
            }
        }

        function tc_delete_checkins_per_event() {

            $wp_events_search = new TC_Events_Search( '', '', -1 );

            $content = '<div class="postbox">';
            $content .= '<h3 class="hndle">' . __( 'Delete Check-ins', 'tc' ) . '</h3>';
            $content .= '<div class="inside">';
            $content .= '<span class="description"><font color="red"><strong>' . __( 'Please note that this is not reversible!', 'tc' ) . '</strong></font></br>' . __( 'Once deleted, check-ins cannot be reverted back!', 'tc' ) . '</span><br/>';
            $content .= '<form method="post">';
            $content .= '<select name="dcheck_in_events[]" class="regular-text dynamic-field-parent" data-placeholder="' . __( 'Select some events to delete all associated checkins' ,'tc' ) . '" multiple="true">';
            $content .= '<option value="all">' . __( 'All Events', 'tc' ) . '</option>';

            foreach ( $wp_events_search->get_results() as $event ) {
                $content .= '<option value="' . esc_attr( $event->ID ) . '">' . $event->post_title . '</option>';
            }

            $content .= '</select><br/><br/>';
            $content .= '<input type="submit" name="dcheck_in_submit" class="button button-primary" value="DELETE CHECKINS" /><br/><br/>';
            $content .= '</form><br/>';
            $content .= '</div>';
            $content .= '</div>';

            echo $content;
        }

        function process_deletion() {

            if ( isset( $_POST['dcheck_in_submit'] ) ) {

                $events_ids = isset( $_POST['dcheck_in_events'] ) ? (array) $_POST['dcheck_in_events'] : [];

                if ( in_array( 'all',  $events_ids ) ) {

                    $events_ids = [];
                    $wp_events_search = new TC_Events_Search( '', '', -1 );

                    foreach ( $wp_events_search->get_results() as $event ) {
                        $events_ids[] = $event->ID;
                    }
                }

                $instance_ids = get_posts( [
                        'posts_per_page' => -1,
                        'post_type' => 'tc_tickets_instances',
                        'post_status' => 'publish',
                        'meta_key' => 'event_id',
                        'meta_value' => $events_ids,
                        'fields' => 'ids'
                    ]
                );

                foreach ( $instance_ids as $instance_id ) {
                    update_post_meta( $instance_id, 'tc_checkins', '' );
                }
            }
        }
    }

    $TC_Delete_Check_Ins_Per_Event = new TC_Delete_Check_Ins_Per_Event();
}

